% author:  Kazantsev Fedor (kazfdr@bionet.nsc.ru)
% copyright LTG ICG SB RAS 2012

% updates: modelsgroup.bionet.nsc.ru
% version: 1.0.0

function result = root4x20(t, y)

%          names of parameters                                usefull comments for parameters
k = [       
 0.6      ; % k(1)  <I(Pin2), K(o)>                             
 1000.0   ; % k(2)  <I(Pin2), K(tau)>                         set to "0.0" for the reverse fountain model, "1000.0" in the dual mechanism model
 0.1      ; % k(3)  <I(Pin2), K(q1)>                            
 2.0      ; % k(4)  <I(Pin2), K(s)>                            
 0.8      ; % k(5)  <I(Pin2), K(q2)>                            
 2.0      ; % k(6)  <I(Pin2), K(s)>                           same as k(4) 
 1000.0   ; % k(7)  <I(Pin3), K(tau)>                         set to "0.0" for the reverse fountain model, "1000.0" in the dual mechanism model
 10.0     ; % k(8)  <I(Pin3), K(q1)>                            
 4.0      ; % k(9)  <I(Pin3), K(s)>                            
 10.0     ; % k(10) <I(Pin3), K(q2)>                            
 4.0      ; % k(11) <I(Pin3), K(s)>                           same as k(9) 
 0.2      ; % k(12) <I(Pin2), K(q3)>                            
 4.0      ; % k(13) <I(Pin2), K(h)>                            
 1.0      ; % k(14) <I(Pin3), K(degr)>                          
 0.005    ; % k(15) <I(auxin), K(Kd)>                             
 0.08     ; % k(16) <K(D)>                                    
 0.0010   ; % k(17) <I(fictiv parameter. Do nothing)>         !!! It is the model specific parameter. Not involved in ODE.
 0.6      ; % k(18) <I(Pin3), K(o)>                             
 1000.0   ; % k(19) <I(Pin1), K(tau)>                         set to "0.0" for the reverse fountain model, "1000.0" in the dual mechanism model
 0.3      ; % k(20) <I(Pin1), K(q1)>                            
 2.0      ; % k(21) <I(Pin1), K(s)>                            
 10.0     ; % k(22) <I(Pin1), K(q2)>                            
 2.0      ; % k(23) <I(Pin1), K(s)>                           same as k(21) 
 1.0      ; % k(24) <I(Pin1), K(q3)>                            
 6.0      ; % k(25) <I(Pin1), K(h)>                            
 0.6      ; % k(26) <I(Pin1), K(o)>                             
 0.5      ; % k(27) <I(auxin), K(alpha)>                      
 0.7      ; % k(28) <I(Pin2), Ratio1(Pin2_bas)>                 
 0.7      ; % k(29) <I(Pin2), Ratio2(Pin2_bas)>                 
 0.5      ; % k(30) <Ratio1~##(PIN3_2)>                       !!! It is the model specific parameter. Do not change.
 0.5      ; % k(31) <Ratio2~##(PIN3_2)>                       !!! It is the model specific parameter. Do not change.
 0.3      ; % k(32) <I(Pin2), Ratio1(Pin2_lat)>                 
 0.3      ; % k(33) <I(Pin2), Ratio2(Pin2_lat)>               
 0.25     ; % k(34) <Ratio1~##(PIN3_4)>                       !!! It is the model specific parameter. Do not change.
 0.25     ; % k(35) <Ratio2~##(PIN3_4)>                       !!! It is the model specific parameter. Do not change.
 0.333    ; % k(36) <Ratio1~##(PIN3_3)>                       !!! It is the model specific parameter. Do not change.
 0.333    ; % k(37) <Ratio2~##(PIN3_3)>                       !!! It is the model specific parameter. Do not change.
 1.0      ; % k(38) <I(a_from_shoot)>                           
 ];

result = [
% y(1)'
 (k(2)*((y(3)/k(3))^k(4))*((1+((y(3)/k(5))^k(6)))^(-1)))-(k(2)*y(1)*(1+((y(3)/k(12))^k(13)))) ;
% y(2)'
 (k(7)*((y(3)/k(8))^k(9))*((1+((y(3)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(2)) ;
% y(3)'
 -(k(16)*y(3))-(k(16)*y(3))-(k(28)*k(1)*y(1)*y(3))-(k(15)*y(3))-(k(32)*k(1)*y(1)*y(3))-(k(30)*k(18)*y(2)*y(3))-(k(30)*k(18)*y(2)*y(3))+(k(16)*y(64))+(k(37)*k(18)*y(63)*y(64))+(k(16)*y(6))+(k(37)*k(18)*y(5)*y(6)) ;
% y(4)'
 (k(2)*((y(6)/k(3))^k(4))*((1+((y(6)/k(5))^k(6)))^(-1)))-(k(2)*y(4)*(1+((y(6)/k(12))^k(13)))) ;
% y(5)'
 (k(7)*((y(6)/k(8))^k(9))*((1+((y(6)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(5)) ;
% y(6)'
 (k(16)*y(3))+(k(29)*k(1)*y(1)*y(3))+(k(37)*k(18)*y(8)*y(9))+(k(31)*k(18)*y(2)*y(3))-(k(15)*y(6))-(k(28)*k(1)*y(4)*y(6))+(k(16)*y(67))+(k(16)*y(9))-(k(32)*k(1)*y(4)*y(6))-(k(16)*y(6))-(k(16)*y(6))-(k(36)*k(18)*y(5)*y(6))-(k(36)*k(18)*y(5)*y(6))-(k(36)*k(18)*y(5)*y(6))+(k(35)*k(18)*y(66)*y(67))-(k(16)*y(6)) ;
% y(7)'
 (k(2)*((y(9)/k(3))^k(4))*((1+((y(9)/k(5))^k(6)))^(-1)))-(k(2)*y(7)*(1+((y(9)/k(12))^k(13)))) ;
% y(8)'
 (k(7)*((y(9)/k(8))^k(9))*((1+((y(9)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(8)) ;
% y(9)'
 -(k(28)*k(1)*y(7)*y(9))-(k(32)*k(1)*y(7)*y(9))+(k(35)*k(18)*y(69)*y(70))-(k(36)*k(18)*y(8)*y(9))-(k(36)*k(18)*y(8)*y(9))-(k(36)*k(18)*y(8)*y(9))+(k(29)*k(1)*y(4)*y(6))+(k(16)*y(12))-(k(16)*y(9))+(k(37)*k(18)*y(11)*y(12))-(k(16)*y(9))-(k(16)*y(9))-(k(15)*y(9))+(k(16)*y(6))+(k(37)*k(18)*y(5)*y(6))+(k(16)*y(70)) ;
% y(10)'
 (k(2)*((y(12)/k(3))^k(4))*((1+((y(12)/k(5))^k(6)))^(-1)))-(k(2)*y(10)*(1+((y(12)/k(12))^k(13)))) ;
% y(11)'
 (k(7)*((y(12)/k(8))^k(9))*((1+((y(12)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(11)) ;
% y(12)'
 (k(29)*k(1)*y(7)*y(9))-(k(32)*k(1)*y(10)*y(12))+(k(35)*k(18)*y(72)*y(73))+(k(37)*k(18)*y(8)*y(9))+(k(37)*k(18)*y(14)*y(15))-(k(15)*y(12))+(k(16)*y(73))-(k(16)*y(12))-(k(16)*y(12))-(k(36)*k(18)*y(11)*y(12))-(k(36)*k(18)*y(11)*y(12))-(k(36)*k(18)*y(11)*y(12))+(k(16)*y(9))-(k(28)*k(1)*y(10)*y(12))+(k(16)*y(15))-(k(16)*y(12)) ;
% y(13)'
 (k(2)*((y(15)/k(3))^k(4))*((1+((y(15)/k(5))^k(6)))^(-1)))-(k(2)*y(13)*(1+((y(15)/k(12))^k(13)))) ;
% y(14)'
 (k(7)*((y(15)/k(8))^k(9))*((1+((y(15)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(14)) ;
% y(15)'
 -(k(28)*k(1)*y(13)*y(15))+(k(35)*k(18)*y(75)*y(76))-(k(36)*k(18)*y(14)*y(15))-(k(36)*k(18)*y(14)*y(15))-(k(36)*k(18)*y(14)*y(15))-(k(16)*y(15))-(k(15)*y(15))+(k(16)*y(12))+(k(16)*y(18))-(k(32)*k(1)*y(13)*y(15))+(k(37)*k(18)*y(11)*y(12))+(k(29)*k(1)*y(10)*y(12))-(k(16)*y(15))-(k(16)*y(15))+(k(16)*y(76))+(k(37)*k(18)*y(17)*y(18)) ;
% y(16)'
 (k(2)*((y(18)/k(3))^k(4))*((1+((y(18)/k(5))^k(6)))^(-1)))-(k(2)*y(16)*(1+((y(18)/k(12))^k(13)))) ;
% y(17)'
 (k(7)*((y(18)/k(8))^k(9))*((1+((y(18)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(17)) ;
% y(18)'
 (k(29)*k(1)*y(13)*y(15))-(k(15)*y(18))+(k(37)*k(18)*y(14)*y(15))+(k(16)*y(79))+(k(37)*k(18)*y(20)*y(21))+(k(16)*y(21))-(k(16)*y(18))-(k(16)*y(18))-(k(16)*y(18))+(k(35)*k(18)*y(78)*y(79))-(k(28)*k(1)*y(16)*y(18))-(k(32)*k(1)*y(16)*y(18))+(k(16)*y(15))-(k(36)*k(18)*y(17)*y(18))-(k(36)*k(18)*y(17)*y(18))-(k(36)*k(18)*y(17)*y(18)) ;
% y(19)'
 (k(2)*((y(21)/k(3))^k(4))*((1+((y(21)/k(5))^k(6)))^(-1)))-(k(2)*y(19)*(1+((y(21)/k(12))^k(13)))) ;
% y(20)'
 (k(7)*((y(21)/k(8))^k(9))*((1+((y(21)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(20)) ;
% y(21)'
 -(k(16)*y(21))+(k(35)*k(18)*y(81)*y(82))-(k(28)*k(1)*y(19)*y(21))-(k(32)*k(1)*y(19)*y(21))-(k(15)*y(21))+(k(16)*y(24))+(k(37)*k(18)*y(23)*y(24))-(k(36)*k(18)*y(20)*y(21))-(k(36)*k(18)*y(20)*y(21))-(k(36)*k(18)*y(20)*y(21))-(k(16)*y(21))-(k(16)*y(21))+(k(16)*y(82))+(k(16)*y(18))+(k(29)*k(1)*y(16)*y(18))+(k(37)*k(18)*y(17)*y(18)) ;
% y(22)'
 (k(2)*((y(24)/k(3))^k(4))*((1+((y(24)/k(5))^k(6)))^(-1)))-(k(2)*y(22)*(1+((y(24)/k(12))^k(13)))) ;
% y(23)'
 (k(7)*((y(24)/k(8))^k(9))*((1+((y(24)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(23)) ;
% y(24)'
 -(k(28)*k(1)*y(22)*y(24))+(k(16)*y(85))+(k(29)*k(1)*y(19)*y(21))+(k(35)*k(18)*y(84)*y(85))+(k(16)*y(27))-(k(16)*y(24))-(k(16)*y(24))-(k(36)*k(18)*y(23)*y(24))-(k(36)*k(18)*y(23)*y(24))-(k(36)*k(18)*y(23)*y(24))+(k(37)*k(18)*y(20)*y(21))+(k(16)*y(21))-(k(32)*k(1)*y(22)*y(24))-(k(16)*y(24))+(k(37)*k(18)*y(26)*y(27))-(k(15)*y(24)) ;
% y(25)'
 (k(2)*((y(27)/k(3))^k(4))*((1+((y(27)/k(5))^k(6)))^(-1)))-(k(2)*y(25)*(1+((y(27)/k(12))^k(13)))) ;
% y(26)'
 (k(7)*((y(27)/k(8))^k(9))*((1+((y(27)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(26)) ;
% y(27)'
 (k(29)*k(1)*y(22)*y(24))+(k(16)*y(88))-(k(32)*k(1)*y(25)*y(27))+(k(16)*y(30))-(k(16)*y(27))-(k(16)*y(27))+(k(16)*y(24))-(k(15)*y(27))+(k(37)*k(18)*y(23)*y(24))-(k(16)*y(27))+(k(37)*k(18)*y(29)*y(30))+(k(35)*k(18)*y(87)*y(88))-(k(36)*k(18)*y(26)*y(27))-(k(36)*k(18)*y(26)*y(27))-(k(36)*k(18)*y(26)*y(27))-(k(28)*k(1)*y(25)*y(27)) ;
% y(28)'
 (k(2)*((y(30)/k(3))^k(4))*((1+((y(30)/k(5))^k(6)))^(-1)))-(k(2)*y(28)*(1+((y(30)/k(12))^k(13)))) ;
% y(29)'
 (k(7)*((y(30)/k(8))^k(9))*((1+((y(30)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(29)) ;
% y(30)'
 (k(37)*k(18)*y(32)*y(33))-(k(15)*y(30))-(k(16)*y(30))-(k(16)*y(30))+(k(16)*y(27))+(k(35)*k(18)*y(90)*y(91))-(k(36)*k(18)*y(29)*y(30))-(k(36)*k(18)*y(29)*y(30))-(k(36)*k(18)*y(29)*y(30))-(k(16)*y(30))+(k(16)*y(91))+(k(37)*k(18)*y(26)*y(27))+(k(29)*k(1)*y(25)*y(27))-(k(28)*k(1)*y(28)*y(30))+(k(16)*y(33))-(k(32)*k(1)*y(28)*y(30)) ;
% y(31)'
 (k(2)*((y(33)/k(3))^k(4))*((1+((y(33)/k(5))^k(6)))^(-1)))-(k(2)*y(31)*(1+((y(33)/k(12))^k(13)))) ;
% y(32)'
 (k(7)*((y(33)/k(8))^k(9))*((1+((y(33)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(32)) ;
% y(33)'
 -(k(16)*y(33))-(k(36)*k(18)*y(32)*y(33))-(k(36)*k(18)*y(32)*y(33))-(k(36)*k(18)*y(32)*y(33))-(k(15)*y(33))+(k(16)*y(30))+(k(16)*y(36))-(k(32)*k(1)*y(31)*y(33))+(k(35)*k(18)*y(93)*y(94))+(k(37)*k(18)*y(29)*y(30))+(k(37)*k(18)*y(35)*y(36))+(k(29)*k(1)*y(28)*y(30))-(k(28)*k(1)*y(31)*y(33))+(k(16)*y(94))-(k(16)*y(33))-(k(16)*y(33)) ;
% y(34)'
 (k(2)*((y(36)/k(3))^k(4))*((1+((y(36)/k(5))^k(6)))^(-1)))-(k(2)*y(34)*(1+((y(36)/k(12))^k(13)))) ;
% y(35)'
 (k(7)*((y(36)/k(8))^k(9))*((1+((y(36)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(35)) ;
% y(36)'
 -(k(15)*y(36))+(k(37)*k(18)*y(32)*y(33))-(k(32)*k(1)*y(34)*y(36))-(k(16)*y(36))-(k(16)*y(36))+(k(16)*y(97))-(k(16)*y(36))-(k(28)*k(1)*y(34)*y(36))-(k(36)*k(18)*y(35)*y(36))-(k(36)*k(18)*y(35)*y(36))-(k(36)*k(18)*y(35)*y(36))+(k(29)*k(1)*y(31)*y(33))+(k(16)*y(33))+(k(16)*y(39))+(k(35)*k(18)*y(96)*y(97))+(k(37)*k(18)*y(38)*y(39)) ;
% y(37)'
 (k(2)*((y(39)/k(3))^k(4))*((1+((y(39)/k(5))^k(6)))^(-1)))-(k(2)*y(37)*(1+((y(39)/k(12))^k(13)))) ;
% y(38)'
 (k(7)*((y(39)/k(8))^k(9))*((1+((y(39)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(38)) ;
% y(39)'
 (k(37)*k(18)*y(41)*y(42))-(k(28)*k(1)*y(37)*y(39))-(k(15)*y(39))+(k(16)*y(36))+(k(16)*y(42))-(k(16)*y(39))+(k(29)*k(1)*y(34)*y(36))+(k(35)*k(18)*y(99)*y(100))-(k(32)*k(1)*y(37)*y(39))+(k(37)*k(18)*y(35)*y(36))+(k(16)*y(100))-(k(16)*y(39))-(k(16)*y(39))-(k(36)*k(18)*y(38)*y(39))-(k(36)*k(18)*y(38)*y(39))-(k(36)*k(18)*y(38)*y(39)) ;
% y(40)'
 (k(2)*((y(42)/k(3))^k(4))*((1+((y(42)/k(5))^k(6)))^(-1)))-(k(2)*y(40)*(1+((y(42)/k(12))^k(13)))) ;
% y(41)'
 (k(7)*((y(42)/k(8))^k(9))*((1+((y(42)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(41)) ;
% y(42)'
 -(k(36)*k(18)*y(41)*y(42))-(k(36)*k(18)*y(41)*y(42))-(k(36)*k(18)*y(41)*y(42))+(k(29)*k(1)*y(37)*y(39))-(k(16)*y(42))+(k(35)*k(18)*y(102)*y(103))-(k(16)*y(42))-(k(16)*y(42))-(k(28)*k(1)*y(40)*y(42))-(k(15)*y(42))+(k(16)*y(103))+(k(37)*k(18)*y(44)*y(45))+(k(16)*y(45))-(k(32)*k(1)*y(40)*y(42))+(k(16)*y(39))+(k(37)*k(18)*y(38)*y(39)) ;
% y(43)'
 (k(2)*((y(45)/k(3))^k(4))*((1+((y(45)/k(5))^k(6)))^(-1)))-(k(2)*y(43)*(1+((y(45)/k(12))^k(13)))) ;
% y(44)'
 (k(7)*((y(45)/k(8))^k(9))*((1+((y(45)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(44)) ;
% y(45)'
 -(k(16)*y(45))+(k(37)*k(18)*y(47)*y(48))+(k(37)*k(18)*y(41)*y(42))+(k(16)*y(48))-(k(32)*k(1)*y(43)*y(45))+(k(16)*y(42))+(k(16)*y(106))+(k(29)*k(1)*y(40)*y(42))-(k(28)*k(1)*y(43)*y(45))-(k(36)*k(18)*y(44)*y(45))-(k(36)*k(18)*y(44)*y(45))-(k(36)*k(18)*y(44)*y(45))-(k(16)*y(45))-(k(16)*y(45))+(k(35)*k(18)*y(105)*y(106))-(k(15)*y(45)) ;
% y(46)'
 (k(2)*((y(48)/k(3))^k(4))*((1+((y(48)/k(5))^k(6)))^(-1)))-(k(2)*y(46)*(1+((y(48)/k(12))^k(13)))) ;
% y(47)'
 (k(7)*((y(48)/k(8))^k(9))*((1+((y(48)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(47)) ;
% y(48)'
 -(k(32)*k(1)*y(46)*y(48))+(k(35)*k(18)*y(108)*y(109))-(k(36)*k(18)*y(47)*y(48))-(k(36)*k(18)*y(47)*y(48))-(k(36)*k(18)*y(47)*y(48))+(k(16)*y(109))+(k(16)*y(51))-(k(28)*k(1)*y(46)*y(48))-(k(15)*y(48))-(k(16)*y(48))-(k(16)*y(48))-(k(16)*y(48))+(k(29)*k(1)*y(43)*y(45))+(k(37)*k(18)*y(50)*y(51))+(k(37)*k(18)*y(44)*y(45))+(k(16)*y(45)) ;
% y(49)'
 (k(2)*((y(51)/k(3))^k(4))*((1+((y(51)/k(5))^k(6)))^(-1)))-(k(2)*y(49)*(1+((y(51)/k(12))^k(13)))) ;
% y(50)'
 (k(7)*((y(51)/k(8))^k(9))*((1+((y(51)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(50)) ;
% y(51)'
 (k(16)*y(54))+(k(37)*k(18)*y(47)*y(48))-(k(16)*y(51))-(k(16)*y(51))+(k(29)*k(1)*y(46)*y(48))+(k(37)*k(18)*y(53)*y(54))+(k(16)*y(48))+(k(35)*k(18)*y(111)*y(112))+(k(16)*y(112))-(k(36)*k(18)*y(50)*y(51))-(k(36)*k(18)*y(50)*y(51))-(k(36)*k(18)*y(50)*y(51))-(k(32)*k(1)*y(49)*y(51))-(k(28)*k(1)*y(49)*y(51))-(k(16)*y(51))-(k(15)*y(51)) ;
% y(52)'
 (k(2)*((y(54)/k(3))^k(4))*((1+((y(54)/k(5))^k(6)))^(-1)))-(k(2)*y(52)*(1+((y(54)/k(12))^k(13)))) ;
% y(53)'
 (k(7)*((y(54)/k(8))^k(9))*((1+((y(54)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(53)) ;
% y(54)'
 (k(16)*y(115))+(k(37)*k(18)*y(56)*y(57))-(k(16)*y(54))-(k(16)*y(54))+(k(16)*y(51))-(k(36)*k(18)*y(53)*y(54))-(k(36)*k(18)*y(53)*y(54))-(k(36)*k(18)*y(53)*y(54))+(k(16)*y(57))-(k(28)*k(1)*y(52)*y(54))-(k(32)*k(1)*y(52)*y(54))+(k(37)*k(18)*y(50)*y(51))-(k(15)*y(54))+(k(29)*k(1)*y(49)*y(51))-(k(16)*y(54))+(k(35)*k(18)*y(114)*y(115)) ;
% y(55)'
 (k(2)*((y(57)/k(3))^k(4))*((1+((y(57)/k(5))^k(6)))^(-1)))-(k(2)*y(55)*(1+((y(57)/k(12))^k(13)))) ;
% y(56)'
 (k(7)*((y(57)/k(8))^k(9))*((1+((y(57)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(56)) ;
% y(57)'
 (k(31)*k(18)*y(59)*y(60))-(k(36)*k(18)*y(56)*y(57))-(k(36)*k(18)*y(56)*y(57))-(k(36)*k(18)*y(56)*y(57))+(k(16)*y(54))+(k(37)*k(18)*y(53)*y(54))-(k(32)*k(1)*y(55)*y(57))+(k(16)*y(118))-(k(16)*y(57))-(k(28)*k(1)*y(55)*y(57))-(k(16)*y(57))-(k(16)*y(57))-(k(15)*y(57))+(k(29)*k(1)*y(52)*y(54))+(k(35)*k(18)*y(117)*y(118))+(k(16)*y(60)) ;
% y(58)'
 (k(2)*((y(60)/k(3))^k(4))*((1+((y(60)/k(5))^k(6)))^(-1)))-(k(2)*y(58)*(1+((y(60)/k(12))^k(13)))) ;
% y(59)'
 (k(7)*((y(60)/k(8))^k(9))*((1+((y(60)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(59)) ;
% y(60)'
 -(k(30)*k(18)*y(59)*y(60))-(k(30)*k(18)*y(59)*y(60))+(k(37)*k(18)*y(56)*y(57))-(k(32)*k(1)*y(58)*y(60))-(k(28)*k(1)*y(58)*y(60))+(k(29)*k(1)*y(55)*y(57))+(k(16)*y(57))-(k(15)*y(60))+(k(16)*y(121))+(k(37)*k(18)*y(120)*y(121))-(k(16)*y(60))-(k(16)*y(60)) ;
% y(61)'
 k(29)*k(1)*y(58)*y(60) ;
% y(62)'
 (k(2)*((y(64)/k(3))^k(4))*((1+((y(64)/k(5))^k(6)))^(-1)))-(k(2)*y(62)*(1+((y(64)/k(12))^k(13)))) ;
% y(63)'
 (k(7)*((y(64)/k(8))^k(9))*((1+((y(64)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(63)) ;
% y(64)'
 (k(16)*y(3))+(k(37)*k(18)*y(123)*y(124))+(k(16)*y(124))+(k(33)*k(1)*y(1)*y(3))+(k(16)*y(67))+(k(31)*k(18)*y(2)*y(3))-(k(32)*k(1)*y(62)*y(64))-(k(16)*y(64))-(k(16)*y(64))-(k(16)*y(64))-(k(28)*k(1)*y(62)*y(64))-(k(15)*y(64))-(k(36)*k(18)*y(63)*y(64))-(k(36)*k(18)*y(63)*y(64))-(k(36)*k(18)*y(63)*y(64))+(k(35)*k(18)*y(66)*y(67)) ;
% y(65)'
 (k(2)*((y(67)/k(3))^k(4))*((1+((y(67)/k(5))^k(6)))^(-1)))-(k(2)*y(65)*(1+((y(67)/k(12))^k(13)))) ;
% y(66)'
 (k(7)*((y(67)/k(8))^k(9))*((1+((y(67)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(66)) ;
% y(67)'
 (k(35)*k(18)*y(69)*y(70))-(k(16)*y(67))-(k(16)*y(67))+(k(16)*y(127))-(k(32)*k(1)*y(65)*y(67))+(k(16)*y(70))+(k(35)*k(18)*y(126)*y(127))+(k(16)*y(64))-(k(16)*y(67))-(k(16)*y(67))+(k(29)*k(1)*y(62)*y(64))+(k(37)*k(18)*y(63)*y(64))+(k(33)*k(1)*y(4)*y(6))+(k(37)*k(18)*y(5)*y(6))-(k(28)*k(1)*y(65)*y(67))-(k(34)*k(18)*y(66)*y(67))-(k(34)*k(18)*y(66)*y(67))-(k(34)*k(18)*y(66)*y(67))-(k(34)*k(18)*y(66)*y(67))-(k(15)*y(67))+(k(16)*y(6)) ;
% y(68)'
 (k(2)*((y(70)/k(3))^k(4))*((1+((y(70)/k(5))^k(6)))^(-1)))-(k(2)*y(68)*(1+((y(70)/k(12))^k(13)))) ;
% y(69)'
 (k(7)*((y(70)/k(8))^k(9))*((1+((y(70)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(69)) ;
% y(70)'
 -(k(15)*y(70))+(k(33)*k(1)*y(7)*y(9))-(k(34)*k(18)*y(69)*y(70))-(k(34)*k(18)*y(69)*y(70))-(k(34)*k(18)*y(69)*y(70))-(k(34)*k(18)*y(69)*y(70))+(k(16)*y(67))+(k(35)*k(18)*y(72)*y(73))+(k(37)*k(18)*y(8)*y(9))-(k(16)*y(70))-(k(16)*y(70))-(k(32)*k(1)*y(68)*y(70))+(k(16)*y(9))+(k(16)*y(130))-(k(28)*k(1)*y(68)*y(70))+(k(16)*y(73))+(k(29)*k(1)*y(65)*y(67))+(k(35)*k(18)*y(66)*y(67))+(k(35)*k(18)*y(129)*y(130))-(k(16)*y(70))-(k(16)*y(70)) ;
% y(71)'
 (k(2)*((y(73)/k(3))^k(4))*((1+((y(73)/k(5))^k(6)))^(-1)))-(k(2)*y(71)*(1+((y(73)/k(12))^k(13)))) ;
% y(72)'
 (k(7)*((y(73)/k(8))^k(9))*((1+((y(73)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(72)) ;
% y(73)'
 (k(33)*k(1)*y(10)*y(12))+(k(35)*k(18)*y(69)*y(70))-(k(34)*k(18)*y(72)*y(73))-(k(34)*k(18)*y(72)*y(73))-(k(34)*k(18)*y(72)*y(73))-(k(34)*k(18)*y(72)*y(73))+(k(35)*k(18)*y(75)*y(76))-(k(16)*y(73))-(k(16)*y(73))+(k(16)*y(70))+(k(16)*y(133))-(k(32)*k(1)*y(71)*y(73))-(k(15)*y(73))+(k(16)*y(76))+(k(37)*k(18)*y(11)*y(12))+(k(29)*k(1)*y(68)*y(70))-(k(16)*y(73))-(k(16)*y(73))+(k(35)*k(18)*y(132)*y(133))-(k(28)*k(1)*y(71)*y(73))+(k(16)*y(12)) ;
% y(74)'
 (k(2)*((y(76)/k(3))^k(4))*((1+((y(76)/k(5))^k(6)))^(-1)))-(k(2)*y(74)*(1+((y(76)/k(12))^k(13)))) ;
% y(75)'
 (k(7)*((y(76)/k(8))^k(9))*((1+((y(76)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(75)) ;
% y(76)'
 -(k(15)*y(76))+(k(16)*y(136))-(k(32)*k(1)*y(74)*y(76))+(k(35)*k(18)*y(72)*y(73))-(k(34)*k(18)*y(75)*y(76))-(k(34)*k(18)*y(75)*y(76))-(k(34)*k(18)*y(75)*y(76))-(k(34)*k(18)*y(75)*y(76))+(k(16)*y(79))+(k(37)*k(18)*y(14)*y(15))-(k(28)*k(1)*y(74)*y(76))+(k(16)*y(15))+(k(35)*k(18)*y(135)*y(136))+(k(35)*k(18)*y(78)*y(79))-(k(16)*y(76))-(k(16)*y(76))+(k(33)*k(1)*y(13)*y(15))+(k(16)*y(73))-(k(16)*y(76))-(k(16)*y(76))+(k(29)*k(1)*y(71)*y(73)) ;
% y(77)'
 (k(2)*((y(79)/k(3))^k(4))*((1+((y(79)/k(5))^k(6)))^(-1)))-(k(2)*y(77)*(1+((y(79)/k(12))^k(13)))) ;
% y(78)'
 (k(7)*((y(79)/k(8))^k(9))*((1+((y(79)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(78)) ;
% y(79)'
 (k(35)*k(18)*y(81)*y(82))-(k(28)*k(1)*y(77)*y(79))-(k(32)*k(1)*y(77)*y(79))+(k(16)*y(139))+(k(35)*k(18)*y(138)*y(139))+(k(35)*k(18)*y(75)*y(76))-(k(16)*y(79))-(k(16)*y(79))+(k(29)*k(1)*y(74)*y(76))-(k(16)*y(79))-(k(16)*y(79))+(k(16)*y(82))+(k(16)*y(18))-(k(34)*k(18)*y(78)*y(79))-(k(34)*k(18)*y(78)*y(79))-(k(34)*k(18)*y(78)*y(79))-(k(34)*k(18)*y(78)*y(79))+(k(16)*y(76))-(k(15)*y(79))+(k(33)*k(1)*y(16)*y(18))+(k(37)*k(18)*y(17)*y(18)) ;
% y(80)'
 (k(2)*((y(82)/k(3))^k(4))*((1+((y(82)/k(5))^k(6)))^(-1)))-(k(2)*y(80)*(1+((y(82)/k(12))^k(13)))) ;
% y(81)'
 (k(7)*((y(82)/k(8))^k(9))*((1+((y(82)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(81)) ;
% y(82)'
 (k(16)*y(21))-(k(34)*k(18)*y(81)*y(82))-(k(34)*k(18)*y(81)*y(82))-(k(34)*k(18)*y(81)*y(82))-(k(34)*k(18)*y(81)*y(82))+(k(29)*k(1)*y(77)*y(79))+(k(35)*k(18)*y(84)*y(85))+(k(35)*k(18)*y(141)*y(142))+(k(33)*k(1)*y(19)*y(21))+(k(16)*y(79))+(k(37)*k(18)*y(20)*y(21))-(k(16)*y(82))-(k(16)*y(82))-(k(16)*y(82))-(k(16)*y(82))+(k(35)*k(18)*y(78)*y(79))-(k(15)*y(82))-(k(28)*k(1)*y(80)*y(82))+(k(16)*y(142))+(k(16)*y(85))-(k(32)*k(1)*y(80)*y(82)) ;
% y(83)'
 (k(2)*((y(85)/k(3))^k(4))*((1+((y(85)/k(5))^k(6)))^(-1)))-(k(2)*y(83)*(1+((y(85)/k(12))^k(13)))) ;
% y(84)'
 (k(7)*((y(85)/k(8))^k(9))*((1+((y(85)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(84)) ;
% y(85)'
 (k(35)*k(18)*y(81)*y(82))-(k(16)*y(85))-(k(16)*y(85))-(k(15)*y(85))-(k(34)*k(18)*y(84)*y(85))-(k(34)*k(18)*y(84)*y(85))-(k(34)*k(18)*y(84)*y(85))-(k(34)*k(18)*y(84)*y(85))+(k(35)*k(18)*y(144)*y(145))+(k(37)*k(18)*y(23)*y(24))+(k(16)*y(88))-(k(28)*k(1)*y(83)*y(85))-(k(32)*k(1)*y(83)*y(85))+(k(16)*y(82))+(k(16)*y(145))+(k(33)*k(1)*y(22)*y(24))+(k(16)*y(24))+(k(29)*k(1)*y(80)*y(82))+(k(35)*k(18)*y(87)*y(88))-(k(16)*y(85))-(k(16)*y(85)) ;
% y(86)'
 (k(2)*((y(88)/k(3))^k(4))*((1+((y(88)/k(5))^k(6)))^(-1)))-(k(2)*y(86)*(1+((y(88)/k(12))^k(13)))) ;
% y(87)'
 (k(7)*((y(88)/k(8))^k(9))*((1+((y(88)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(87)) ;
% y(88)'
 -(k(16)*y(88))-(k(16)*y(88))+(k(16)*y(91))+(k(33)*k(1)*y(25)*y(27))+(k(35)*k(18)*y(84)*y(85))+(k(35)*k(18)*y(147)*y(148))-(k(28)*k(1)*y(86)*y(88))+(k(35)*k(18)*y(90)*y(91))-(k(16)*y(88))-(k(16)*y(88))+(k(29)*k(1)*y(83)*y(85))-(k(15)*y(88))+(k(16)*y(27))+(k(16)*y(148))-(k(32)*k(1)*y(86)*y(88))-(k(34)*k(18)*y(87)*y(88))-(k(34)*k(18)*y(87)*y(88))-(k(34)*k(18)*y(87)*y(88))-(k(34)*k(18)*y(87)*y(88))+(k(37)*k(18)*y(26)*y(27))+(k(16)*y(85)) ;
% y(89)'
 (k(2)*((y(91)/k(3))^k(4))*((1+((y(91)/k(5))^k(6)))^(-1)))-(k(2)*y(89)*(1+((y(91)/k(12))^k(13)))) ;
% y(90)'
 (k(7)*((y(91)/k(8))^k(9))*((1+((y(91)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(90)) ;
% y(91)'
 -(k(15)*y(91))-(k(16)*y(91))-(k(16)*y(91))-(k(32)*k(1)*y(89)*y(91))-(k(28)*k(1)*y(89)*y(91))+(k(29)*k(1)*y(86)*y(88))-(k(34)*k(18)*y(90)*y(91))-(k(34)*k(18)*y(90)*y(91))-(k(34)*k(18)*y(90)*y(91))-(k(34)*k(18)*y(90)*y(91))+(k(16)*y(151))+(k(35)*k(18)*y(93)*y(94))+(k(16)*y(88))+(k(37)*k(18)*y(29)*y(30))+(k(16)*y(30))+(k(16)*y(94))+(k(35)*k(18)*y(87)*y(88))-(k(16)*y(91))-(k(16)*y(91))+(k(35)*k(18)*y(150)*y(151))+(k(33)*k(1)*y(28)*y(30)) ;
% y(92)'
 (k(2)*((y(94)/k(3))^k(4))*((1+((y(94)/k(5))^k(6)))^(-1)))-(k(2)*y(92)*(1+((y(94)/k(12))^k(13)))) ;
% y(93)'
 (k(7)*((y(94)/k(8))^k(9))*((1+((y(94)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(93)) ;
% y(94)'
 (k(16)*y(91))+(k(16)*y(33))+(k(37)*k(18)*y(32)*y(33))-(k(32)*k(1)*y(92)*y(94))+(k(29)*k(1)*y(89)*y(91))+(k(35)*k(18)*y(90)*y(91))+(k(33)*k(1)*y(31)*y(33))-(k(34)*k(18)*y(93)*y(94))-(k(34)*k(18)*y(93)*y(94))-(k(34)*k(18)*y(93)*y(94))-(k(34)*k(18)*y(93)*y(94))+(k(16)*y(97))-(k(16)*y(94))-(k(16)*y(94))+(k(16)*y(154))-(k(28)*k(1)*y(92)*y(94))+(k(35)*k(18)*y(153)*y(154))-(k(16)*y(94))-(k(16)*y(94))-(k(15)*y(94))+(k(35)*k(18)*y(96)*y(97)) ;
% y(95)'
 (k(2)*((y(97)/k(3))^k(4))*((1+((y(97)/k(5))^k(6)))^(-1)))-(k(2)*y(95)*(1+((y(97)/k(12))^k(13)))) ;
% y(96)'
 (k(7)*((y(97)/k(8))^k(9))*((1+((y(97)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(96)) ;
% y(97)'
 (k(16)*y(100))+(k(33)*k(1)*y(34)*y(36))-(k(15)*y(97))-(k(16)*y(97))-(k(16)*y(97))+(k(16)*y(36))+(k(35)*k(18)*y(93)*y(94))+(k(16)*y(157))+(k(35)*k(18)*y(99)*y(100))+(k(35)*k(18)*y(156)*y(157))-(k(16)*y(97))-(k(16)*y(97))-(k(28)*k(1)*y(95)*y(97))+(k(16)*y(94))+(k(37)*k(18)*y(35)*y(36))+(k(29)*k(1)*y(92)*y(94))-(k(32)*k(1)*y(95)*y(97))-(k(34)*k(18)*y(96)*y(97))-(k(34)*k(18)*y(96)*y(97))-(k(34)*k(18)*y(96)*y(97))-(k(34)*k(18)*y(96)*y(97)) ;
% y(98)'
 (k(2)*((y(100)/k(3))^k(4))*((1+((y(100)/k(5))^k(6)))^(-1)))-(k(2)*y(98)*(1+((y(100)/k(12))^k(13)))) ;
% y(99)'
 (k(7)*((y(100)/k(8))^k(9))*((1+((y(100)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(99)) ;
% y(100)'
 -(k(32)*k(1)*y(98)*y(100))-(k(16)*y(100))-(k(16)*y(100))+(k(16)*y(103))+(k(35)*k(18)*y(102)*y(103))-(k(28)*k(1)*y(98)*y(100))+(k(16)*y(39))-(k(34)*k(18)*y(99)*y(100))-(k(34)*k(18)*y(99)*y(100))-(k(34)*k(18)*y(99)*y(100))-(k(34)*k(18)*y(99)*y(100))+(k(16)*y(97))+(k(33)*k(1)*y(37)*y(39))+(k(29)*k(1)*y(95)*y(97))-(k(15)*y(100))-(k(16)*y(100))-(k(16)*y(100))+(k(35)*k(18)*y(159)*y(160))+(k(16)*y(160))+(k(35)*k(18)*y(96)*y(97))+(k(37)*k(18)*y(38)*y(39)) ;
% y(101)'
 (k(2)*((y(103)/k(3))^k(4))*((1+((y(103)/k(5))^k(6)))^(-1)))-(k(2)*y(101)*(1+((y(103)/k(12))^k(13)))) ;
% y(102)'
 (k(7)*((y(103)/k(8))^k(9))*((1+((y(103)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(102)) ;
% y(103)'
 (k(16)*y(100))-(k(16)*y(103))-(k(16)*y(103))+(k(35)*k(18)*y(162)*y(163))+(k(37)*k(18)*y(41)*y(42))-(k(15)*y(103))+(k(16)*y(42))-(k(34)*k(18)*y(102)*y(103))-(k(34)*k(18)*y(102)*y(103))-(k(34)*k(18)*y(102)*y(103))-(k(34)*k(18)*y(102)*y(103))+(k(29)*k(1)*y(98)*y(100))+(k(35)*k(18)*y(99)*y(100))+(k(16)*y(163))-(k(16)*y(103))-(k(16)*y(103))+(k(33)*k(1)*y(40)*y(42))-(k(28)*k(1)*y(101)*y(103))+(k(35)*k(18)*y(105)*y(106))+(k(16)*y(106))-(k(32)*k(1)*y(101)*y(103)) ;
% y(104)'
 (k(2)*((y(106)/k(3))^k(4))*((1+((y(106)/k(5))^k(6)))^(-1)))-(k(2)*y(104)*(1+((y(106)/k(12))^k(13)))) ;
% y(105)'
 (k(7)*((y(106)/k(8))^k(9))*((1+((y(106)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(105)) ;
% y(106)'
 -(k(15)*y(106))+(k(16)*y(166))+(k(35)*k(18)*y(108)*y(109))+(k(16)*y(45))+(k(16)*y(103))+(k(35)*k(18)*y(165)*y(166))+(k(33)*k(1)*y(43)*y(45))+(k(35)*k(18)*y(102)*y(103))+(k(16)*y(109))-(k(16)*y(106))-(k(16)*y(106))-(k(32)*k(1)*y(104)*y(106))-(k(28)*k(1)*y(104)*y(106))+(k(37)*k(18)*y(44)*y(45))+(k(29)*k(1)*y(101)*y(103))-(k(34)*k(18)*y(105)*y(106))-(k(34)*k(18)*y(105)*y(106))-(k(34)*k(18)*y(105)*y(106))-(k(34)*k(18)*y(105)*y(106))-(k(16)*y(106))-(k(16)*y(106)) ;
% y(107)'
 (k(2)*((y(109)/k(3))^k(4))*((1+((y(109)/k(5))^k(6)))^(-1)))-(k(2)*y(107)*(1+((y(109)/k(12))^k(13)))) ;
% y(108)'
 (k(7)*((y(109)/k(8))^k(9))*((1+((y(109)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(108)) ;
% y(109)'
 (k(16)*y(169))+(k(33)*k(1)*y(46)*y(48))-(k(34)*k(18)*y(108)*y(109))-(k(34)*k(18)*y(108)*y(109))-(k(34)*k(18)*y(108)*y(109))-(k(34)*k(18)*y(108)*y(109))+(k(37)*k(18)*y(47)*y(48))-(k(16)*y(109))-(k(16)*y(109))+(k(16)*y(112))+(k(35)*k(18)*y(168)*y(169))+(k(16)*y(48))-(k(16)*y(109))-(k(16)*y(109))+(k(35)*k(18)*y(111)*y(112))+(k(29)*k(1)*y(104)*y(106))-(k(15)*y(109))+(k(35)*k(18)*y(105)*y(106))-(k(28)*k(1)*y(107)*y(109))+(k(16)*y(106))-(k(32)*k(1)*y(107)*y(109)) ;
% y(110)'
 (k(2)*((y(112)/k(3))^k(4))*((1+((y(112)/k(5))^k(6)))^(-1)))-(k(2)*y(110)*(1+((y(112)/k(12))^k(13)))) ;
% y(111)'
 (k(7)*((y(112)/k(8))^k(9))*((1+((y(112)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(111)) ;
% y(112)'
 (k(35)*k(18)*y(108)*y(109))-(k(16)*y(112))-(k(16)*y(112))-(k(28)*k(1)*y(110)*y(112))-(k(32)*k(1)*y(110)*y(112))+(k(16)*y(109))-(k(34)*k(18)*y(111)*y(112))-(k(34)*k(18)*y(111)*y(112))-(k(34)*k(18)*y(111)*y(112))-(k(34)*k(18)*y(111)*y(112))-(k(16)*y(112))-(k(16)*y(112))+(k(35)*k(18)*y(171)*y(172))+(k(37)*k(18)*y(50)*y(51))+(k(33)*k(1)*y(49)*y(51))+(k(16)*y(51))+(k(29)*k(1)*y(107)*y(109))+(k(16)*y(172))+(k(35)*k(18)*y(114)*y(115))-(k(15)*y(112))+(k(16)*y(115)) ;
% y(113)'
 (k(2)*((y(115)/k(3))^k(4))*((1+((y(115)/k(5))^k(6)))^(-1)))-(k(2)*y(113)*(1+((y(115)/k(12))^k(13)))) ;
% y(114)'
 (k(7)*((y(115)/k(8))^k(9))*((1+((y(115)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(114)) ;
% y(115)'
 -(k(16)*y(115))-(k(16)*y(115))-(k(28)*k(1)*y(113)*y(115))+(k(16)*y(112))+(k(37)*k(18)*y(53)*y(54))+(k(29)*k(1)*y(110)*y(112))-(k(15)*y(115))+(k(35)*k(18)*y(111)*y(112))+(k(33)*k(1)*y(52)*y(54))+(k(16)*y(118))+(k(35)*k(18)*y(117)*y(118))+(k(16)*y(54))+(k(16)*y(175))+(k(35)*k(18)*y(174)*y(175))-(k(34)*k(18)*y(114)*y(115))-(k(34)*k(18)*y(114)*y(115))-(k(34)*k(18)*y(114)*y(115))-(k(34)*k(18)*y(114)*y(115))-(k(32)*k(1)*y(113)*y(115))-(k(16)*y(115))-(k(16)*y(115)) ;
% y(116)'
 (k(2)*((y(118)/k(3))^k(4))*((1+((y(118)/k(5))^k(6)))^(-1)))-(k(2)*y(116)*(1+((y(118)/k(12))^k(13)))) ;
% y(117)'
 (k(7)*((y(118)/k(8))^k(9))*((1+((y(118)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(117)) ;
% y(118)'
 -(k(15)*y(118))+(k(37)*k(18)*y(56)*y(57))+(k(29)*k(1)*y(113)*y(115))+(k(35)*k(18)*y(177)*y(178))+(k(33)*k(1)*y(55)*y(57))+(k(16)*y(178))-(k(16)*y(118))-(k(16)*y(118))+(k(16)*y(57))+(k(16)*y(121))-(k(16)*y(118))-(k(16)*y(118))+(k(37)*k(18)*y(120)*y(121))-(k(28)*k(1)*y(116)*y(118))-(k(34)*k(18)*y(117)*y(118))-(k(34)*k(18)*y(117)*y(118))-(k(34)*k(18)*y(117)*y(118))-(k(34)*k(18)*y(117)*y(118))-(k(32)*k(1)*y(116)*y(118))+(k(35)*k(18)*y(114)*y(115))+(k(16)*y(115)) ;
% y(119)'
 (k(2)*((y(121)/k(3))^k(4))*((1+((y(121)/k(5))^k(6)))^(-1)))-(k(2)*y(119)*(1+((y(121)/k(12))^k(13)))) ;
% y(120)'
 (k(7)*((y(121)/k(8))^k(9))*((1+((y(121)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(120)) ;
% y(121)'
 (k(31)*k(18)*y(59)*y(60))-(k(28)*k(1)*y(119)*y(121))+(k(33)*k(1)*y(58)*y(60))-(k(32)*k(1)*y(119)*y(121))+(k(16)*y(181))-(k(16)*y(121))-(k(16)*y(121))-(k(16)*y(121))+(k(16)*y(118))-(k(36)*k(18)*y(120)*y(121))-(k(36)*k(18)*y(120)*y(121))-(k(36)*k(18)*y(120)*y(121))+(k(29)*k(1)*y(116)*y(118))+(k(35)*k(18)*y(117)*y(118))+(k(37)*k(18)*y(180)*y(181))-(k(15)*y(121))+(k(16)*y(60)) ;
% y(122)'
 k(29)*k(1)*y(119)*y(121) ;
% y(123)'
 (k(7)*((y(124)/k(8))^k(9))*((1+((y(124)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(123)) ;
% y(124)'
 -(k(36)*k(18)*y(123)*y(124))-(k(36)*k(18)*y(123)*y(124))-(k(36)*k(18)*y(123)*y(124))-(k(16)*y(124))-(k(16)*y(124))-(k(15)*y(124))+(k(16)*y(127))-(k(16)*y(124))+(k(33)*k(1)*y(62)*y(64))+(k(35)*k(18)*y(126)*y(127))+(k(16)*y(64))+(k(16)*y(183))+(k(37)*k(18)*y(63)*y(64))+(k(26)*y(125)*y(127))+(k(37)*k(18)*y(182)*y(183)) ;
% y(125)'
 (k(19)*((y(127)/k(20))^k(21))*((1+((y(127)/k(22))^k(23)))^(-1)))-(k(19)*y(125)*(1+((y(127)/k(24))^k(25)))) ;
% y(126)'
 (k(7)*((y(127)/k(8))^k(9))*((1+((y(127)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(126)) ;
% y(127)'
 (k(37)*k(18)*y(123)*y(124))+(k(26)*y(128)*y(130))-(k(16)*y(127))-(k(16)*y(127))-(k(16)*y(127))-(k(16)*y(127))+(k(33)*k(1)*y(65)*y(67))+(k(16)*y(124))-(k(34)*k(18)*y(126)*y(127))-(k(34)*k(18)*y(126)*y(127))-(k(34)*k(18)*y(126)*y(127))-(k(34)*k(18)*y(126)*y(127))-(k(15)*y(127))+(k(16)*y(67))+(k(16)*y(130))+(k(16)*y(186))-(k(26)*y(125)*y(127))+(k(35)*k(18)*y(66)*y(67))+(k(35)*k(18)*y(129)*y(130))+(k(35)*k(18)*y(185)*y(186)) ;
% y(128)'
 (k(19)*((y(130)/k(20))^k(21))*((1+((y(130)/k(22))^k(23)))^(-1)))-(k(19)*y(128)*(1+((y(130)/k(24))^k(25)))) ;
% y(129)'
 (k(7)*((y(130)/k(8))^k(9))*((1+((y(130)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(129)) ;
% y(130)'
 (k(26)*y(131)*y(133))-(k(26)*y(128)*y(130))+(k(35)*k(18)*y(69)*y(70))+(k(16)*y(127))+(k(35)*k(18)*y(188)*y(189))+(k(16)*y(189))+(k(16)*y(133))+(k(33)*k(1)*y(68)*y(70))+(k(35)*k(18)*y(126)*y(127))-(k(15)*y(130))-(k(16)*y(130))-(k(16)*y(130))-(k(16)*y(130))-(k(16)*y(130))+(k(35)*k(18)*y(132)*y(133))-(k(34)*k(18)*y(129)*y(130))-(k(34)*k(18)*y(129)*y(130))-(k(34)*k(18)*y(129)*y(130))-(k(34)*k(18)*y(129)*y(130))+(k(16)*y(70)) ;
% y(131)'
 (k(19)*((y(133)/k(20))^k(21))*((1+((y(133)/k(22))^k(23)))^(-1)))-(k(19)*y(131)*(1+((y(133)/k(24))^k(25)))) ;
% y(132)'
 (k(7)*((y(133)/k(8))^k(9))*((1+((y(133)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(132)) ;
% y(133)'
 (k(16)*y(136))+(k(26)*y(134)*y(136))-(k(26)*y(131)*y(133))+(k(35)*k(18)*y(72)*y(73))+(k(35)*k(18)*y(191)*y(192))+(k(16)*y(73))-(k(16)*y(133))-(k(16)*y(133))-(k(16)*y(133))-(k(16)*y(133))+(k(33)*k(1)*y(71)*y(73))+(k(35)*k(18)*y(135)*y(136))-(k(15)*y(133))+(k(16)*y(130))-(k(34)*k(18)*y(132)*y(133))-(k(34)*k(18)*y(132)*y(133))-(k(34)*k(18)*y(132)*y(133))-(k(34)*k(18)*y(132)*y(133))+(k(35)*k(18)*y(129)*y(130))+(k(16)*y(192)) ;
% y(134)'
 (k(19)*((y(136)/k(20))^k(21))*((1+((y(136)/k(22))^k(23)))^(-1)))-(k(19)*y(134)*(1+((y(136)/k(24))^k(25)))) ;
% y(135)'
 (k(7)*((y(136)/k(8))^k(9))*((1+((y(136)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(135)) ;
% y(136)'
 -(k(16)*y(136))-(k(16)*y(136))-(k(16)*y(136))-(k(16)*y(136))-(k(26)*y(134)*y(136))+(k(33)*k(1)*y(74)*y(76))+(k(16)*y(139))+(k(35)*k(18)*y(138)*y(139))+(k(35)*k(18)*y(75)*y(76))+(k(16)*y(133))-(k(34)*k(18)*y(135)*y(136))-(k(34)*k(18)*y(135)*y(136))-(k(34)*k(18)*y(135)*y(136))-(k(34)*k(18)*y(135)*y(136))+(k(35)*k(18)*y(194)*y(195))+(k(16)*y(195))+(k(26)*y(137)*y(139))+(k(35)*k(18)*y(132)*y(133))+(k(16)*y(76))-(k(15)*y(136)) ;
% y(137)'
 (k(19)*((y(139)/k(20))^k(21))*((1+((y(139)/k(22))^k(23)))^(-1)))-(k(19)*y(137)*(1+((y(139)/k(24))^k(25)))) ;
% y(138)'
 (k(7)*((y(139)/k(8))^k(9))*((1+((y(139)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(138)) ;
% y(139)'
 (k(16)*y(136))+(k(33)*k(1)*y(77)*y(79))+(k(35)*k(18)*y(141)*y(142))-(k(16)*y(139))-(k(16)*y(139))-(k(16)*y(139))-(k(16)*y(139))-(k(34)*k(18)*y(138)*y(139))-(k(34)*k(18)*y(138)*y(139))-(k(34)*k(18)*y(138)*y(139))-(k(34)*k(18)*y(138)*y(139))+(k(16)*y(79))+(k(35)*k(18)*y(197)*y(198))+(k(35)*k(18)*y(135)*y(136))+(k(16)*y(198))+(k(35)*k(18)*y(78)*y(79))+(k(16)*y(142))+(k(26)*y(140)*y(142))-(k(26)*y(137)*y(139))-(k(15)*y(139)) ;
% y(140)'
 (k(19)*((y(142)/k(20))^k(21))*((1+((y(142)/k(22))^k(23)))^(-1)))-(k(19)*y(140)*(1+((y(142)/k(24))^k(25)))) ;
% y(141)'
 (k(7)*((y(142)/k(8))^k(9))*((1+((y(142)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(141)) ;
% y(142)'
 (k(35)*k(18)*y(81)*y(82))+(k(26)*y(143)*y(145))-(k(34)*k(18)*y(141)*y(142))-(k(34)*k(18)*y(141)*y(142))-(k(34)*k(18)*y(141)*y(142))-(k(34)*k(18)*y(141)*y(142))+(k(16)*y(139))-(k(15)*y(142))+(k(35)*k(18)*y(138)*y(139))+(k(35)*k(18)*y(144)*y(145))+(k(16)*y(201))+(k(16)*y(145))+(k(16)*y(82))-(k(16)*y(142))-(k(16)*y(142))-(k(16)*y(142))-(k(16)*y(142))-(k(26)*y(140)*y(142))+(k(35)*k(18)*y(200)*y(201))+(k(33)*k(1)*y(80)*y(82)) ;
% y(143)'
 (k(19)*((y(145)/k(20))^k(21))*((1+((y(145)/k(22))^k(23)))^(-1)))-(k(19)*y(143)*(1+((y(145)/k(24))^k(25)))) ;
% y(144)'
 (k(7)*((y(145)/k(8))^k(9))*((1+((y(145)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(144)) ;
% y(145)'
 (k(16)*y(204))+(k(16)*y(85))+(k(35)*k(18)*y(84)*y(85))-(k(26)*y(143)*y(145))+(k(35)*k(18)*y(141)*y(142))-(k(34)*k(18)*y(144)*y(145))-(k(34)*k(18)*y(144)*y(145))-(k(34)*k(18)*y(144)*y(145))-(k(34)*k(18)*y(144)*y(145))+(k(35)*k(18)*y(147)*y(148))-(k(15)*y(145))+(k(33)*k(1)*y(83)*y(85))-(k(16)*y(145))-(k(16)*y(145))-(k(16)*y(145))-(k(16)*y(145))+(k(26)*y(146)*y(148))+(k(16)*y(148))+(k(35)*k(18)*y(203)*y(204))+(k(16)*y(142)) ;
% y(146)'
 (k(19)*((y(148)/k(20))^k(21))*((1+((y(148)/k(22))^k(23)))^(-1)))-(k(19)*y(146)*(1+((y(148)/k(24))^k(25)))) ;
% y(147)'
 (k(7)*((y(148)/k(8))^k(9))*((1+((y(148)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(147)) ;
% y(148)'
 (k(16)*y(88))+(k(26)*y(149)*y(151))+(k(35)*k(18)*y(144)*y(145))-(k(34)*k(18)*y(147)*y(148))-(k(34)*k(18)*y(147)*y(148))-(k(34)*k(18)*y(147)*y(148))-(k(34)*k(18)*y(147)*y(148))+(k(16)*y(151))+(k(16)*y(145))-(k(15)*y(148))-(k(26)*y(146)*y(148))-(k(16)*y(148))-(k(16)*y(148))-(k(16)*y(148))-(k(16)*y(148))+(k(33)*k(1)*y(86)*y(88))+(k(35)*k(18)*y(206)*y(207))+(k(35)*k(18)*y(87)*y(88))+(k(35)*k(18)*y(150)*y(151))+(k(16)*y(207)) ;
% y(149)'
 (k(19)*((y(151)/k(20))^k(21))*((1+((y(151)/k(22))^k(23)))^(-1)))-(k(19)*y(149)*(1+((y(151)/k(24))^k(25)))) ;
% y(150)'
 (k(7)*((y(151)/k(8))^k(9))*((1+((y(151)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(150)) ;
% y(151)'
 -(k(26)*y(149)*y(151))+(k(33)*k(1)*y(89)*y(91))+(k(35)*k(18)*y(209)*y(210))-(k(15)*y(151))+(k(26)*y(152)*y(154))+(k(35)*k(18)*y(147)*y(148))+(k(35)*k(18)*y(90)*y(91))+(k(16)*y(210))-(k(16)*y(151))-(k(16)*y(151))-(k(16)*y(151))-(k(16)*y(151))+(k(16)*y(148))+(k(16)*y(91))+(k(16)*y(154))-(k(34)*k(18)*y(150)*y(151))-(k(34)*k(18)*y(150)*y(151))-(k(34)*k(18)*y(150)*y(151))-(k(34)*k(18)*y(150)*y(151))+(k(35)*k(18)*y(153)*y(154)) ;
% y(152)'
 (k(19)*((y(154)/k(20))^k(21))*((1+((y(154)/k(22))^k(23)))^(-1)))-(k(19)*y(152)*(1+((y(154)/k(24))^k(25)))) ;
% y(153)'
 (k(7)*((y(154)/k(8))^k(9))*((1+((y(154)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(153)) ;
% y(154)'
 (k(26)*y(155)*y(157))+(k(33)*k(1)*y(92)*y(94))-(k(26)*y(152)*y(154))+(k(16)*y(151))+(k(35)*k(18)*y(93)*y(94))+(k(35)*k(18)*y(212)*y(213))+(k(16)*y(157))+(k(35)*k(18)*y(156)*y(157))-(k(16)*y(154))-(k(16)*y(154))-(k(16)*y(154))-(k(16)*y(154))+(k(16)*y(213))+(k(35)*k(18)*y(150)*y(151))-(k(34)*k(18)*y(153)*y(154))-(k(34)*k(18)*y(153)*y(154))-(k(34)*k(18)*y(153)*y(154))-(k(34)*k(18)*y(153)*y(154))+(k(16)*y(94))-(k(15)*y(154)) ;
% y(155)'
 (k(19)*((y(157)/k(20))^k(21))*((1+((y(157)/k(22))^k(23)))^(-1)))-(k(19)*y(155)*(1+((y(157)/k(24))^k(25)))) ;
% y(156)'
 (k(7)*((y(157)/k(8))^k(9))*((1+((y(157)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(156)) ;
% y(157)'
 -(k(26)*y(155)*y(157))+(k(16)*y(216))+(k(16)*y(97))-(k(16)*y(157))-(k(16)*y(157))-(k(16)*y(157))-(k(16)*y(157))-(k(34)*k(18)*y(156)*y(157))-(k(34)*k(18)*y(156)*y(157))-(k(34)*k(18)*y(156)*y(157))-(k(34)*k(18)*y(156)*y(157))+(k(26)*y(158)*y(160))+(k(35)*k(18)*y(215)*y(216))+(k(16)*y(154))+(k(33)*k(1)*y(95)*y(97))+(k(35)*k(18)*y(159)*y(160))+(k(35)*k(18)*y(153)*y(154))-(k(15)*y(157))+(k(16)*y(160))+(k(35)*k(18)*y(96)*y(97)) ;
% y(158)'
 (k(19)*((y(160)/k(20))^k(21))*((1+((y(160)/k(22))^k(23)))^(-1)))-(k(19)*y(158)*(1+((y(160)/k(24))^k(25)))) ;
% y(159)'
 (k(7)*((y(160)/k(8))^k(9))*((1+((y(160)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(159)) ;
% y(160)'
 (k(33)*k(1)*y(98)*y(100))+(k(26)*y(161)*y(163))+(k(35)*k(18)*y(162)*y(163))-(k(15)*y(160))+(k(16)*y(219))+(k(16)*y(157))+(k(35)*k(18)*y(99)*y(100))+(k(35)*k(18)*y(156)*y(157))+(k(16)*y(163))+(k(35)*k(18)*y(218)*y(219))-(k(26)*y(158)*y(160))+(k(16)*y(100))-(k(34)*k(18)*y(159)*y(160))-(k(34)*k(18)*y(159)*y(160))-(k(34)*k(18)*y(159)*y(160))-(k(34)*k(18)*y(159)*y(160))-(k(16)*y(160))-(k(16)*y(160))-(k(16)*y(160))-(k(16)*y(160)) ;
% y(161)'
 (k(19)*((y(163)/k(20))^k(21))*((1+((y(163)/k(22))^k(23)))^(-1)))-(k(19)*y(161)*(1+((y(163)/k(24))^k(25)))) ;
% y(162)'
 (k(7)*((y(163)/k(8))^k(9))*((1+((y(163)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(162)) ;
% y(163)'
 (k(16)*y(166))-(k(26)*y(161)*y(163))+(k(16)*y(222))-(k(34)*k(18)*y(162)*y(163))-(k(34)*k(18)*y(162)*y(163))-(k(34)*k(18)*y(162)*y(163))-(k(34)*k(18)*y(162)*y(163))+(k(35)*k(18)*y(165)*y(166))+(k(35)*k(18)*y(102)*y(103))-(k(15)*y(163))+(k(26)*y(164)*y(166))-(k(16)*y(163))-(k(16)*y(163))-(k(16)*y(163))-(k(16)*y(163))+(k(16)*y(103))+(k(35)*k(18)*y(159)*y(160))+(k(16)*y(160))+(k(33)*k(1)*y(101)*y(103))+(k(35)*k(18)*y(221)*y(222)) ;
% y(164)'
 (k(19)*((y(166)/k(20))^k(21))*((1+((y(166)/k(22))^k(23)))^(-1)))-(k(19)*y(164)*(1+((y(166)/k(24))^k(25)))) ;
% y(165)'
 (k(7)*((y(166)/k(8))^k(9))*((1+((y(166)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(165)) ;
% y(166)'
 -(k(16)*y(166))-(k(16)*y(166))-(k(16)*y(166))-(k(16)*y(166))+(k(16)*y(169))+(k(35)*k(18)*y(162)*y(163))+(k(26)*y(167)*y(169))+(k(35)*k(18)*y(224)*y(225))-(k(34)*k(18)*y(165)*y(166))-(k(34)*k(18)*y(165)*y(166))-(k(34)*k(18)*y(165)*y(166))-(k(34)*k(18)*y(165)*y(166))+(k(35)*k(18)*y(168)*y(169))-(k(26)*y(164)*y(166))+(k(16)*y(106))+(k(33)*k(1)*y(104)*y(106))+(k(16)*y(163))+(k(16)*y(225))+(k(35)*k(18)*y(105)*y(106))-(k(15)*y(166)) ;
% y(167)'
 (k(19)*((y(169)/k(20))^k(21))*((1+((y(169)/k(22))^k(23)))^(-1)))-(k(19)*y(167)*(1+((y(169)/k(24))^k(25)))) ;
% y(168)'
 (k(7)*((y(169)/k(8))^k(9))*((1+((y(169)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(168)) ;
% y(169)'
 (k(16)*y(166))-(k(16)*y(169))-(k(16)*y(169))-(k(16)*y(169))-(k(16)*y(169))+(k(35)*k(18)*y(108)*y(109))+(k(16)*y(109))-(k(26)*y(167)*y(169))+(k(35)*k(18)*y(165)*y(166))+(k(16)*y(228))-(k(34)*k(18)*y(168)*y(169))-(k(34)*k(18)*y(168)*y(169))-(k(34)*k(18)*y(168)*y(169))-(k(34)*k(18)*y(168)*y(169))+(k(35)*k(18)*y(227)*y(228))+(k(35)*k(18)*y(171)*y(172))+(k(26)*y(170)*y(172))-(k(15)*y(169))+(k(33)*k(1)*y(107)*y(109))+(k(16)*y(172)) ;
% y(170)'
 (k(19)*((y(172)/k(20))^k(21))*((1+((y(172)/k(22))^k(23)))^(-1)))-(k(19)*y(170)*(1+((y(172)/k(24))^k(25)))) ;
% y(171)'
 (k(7)*((y(172)/k(8))^k(9))*((1+((y(172)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(171)) ;
% y(172)'
 (k(16)*y(169))+(k(26)*y(173)*y(175))+(k(33)*k(1)*y(110)*y(112))+(k(35)*k(18)*y(168)*y(169))+(k(35)*k(18)*y(111)*y(112))+(k(35)*k(18)*y(230)*y(231))+(k(16)*y(112))-(k(34)*k(18)*y(171)*y(172))-(k(34)*k(18)*y(171)*y(172))-(k(34)*k(18)*y(171)*y(172))-(k(34)*k(18)*y(171)*y(172))-(k(26)*y(170)*y(172))+(k(16)*y(175))+(k(16)*y(231))+(k(35)*k(18)*y(174)*y(175))-(k(15)*y(172))-(k(16)*y(172))-(k(16)*y(172))-(k(16)*y(172))-(k(16)*y(172)) ;
% y(173)'
 (k(19)*((y(175)/k(20))^k(21))*((1+((y(175)/k(22))^k(23)))^(-1)))-(k(19)*y(173)*(1+((y(175)/k(24))^k(25)))) ;
% y(174)'
 (k(7)*((y(175)/k(8))^k(9))*((1+((y(175)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(174)) ;
% y(175)'
 (k(16)*y(115))-(k(15)*y(175))-(k(26)*y(173)*y(175))+(k(35)*k(18)*y(177)*y(178))+(k(16)*y(178))+(k(26)*y(176)*y(178))+(k(16)*y(234))+(k(35)*k(18)*y(171)*y(172))-(k(16)*y(175))-(k(16)*y(175))-(k(16)*y(175))-(k(16)*y(175))-(k(34)*k(18)*y(174)*y(175))-(k(34)*k(18)*y(174)*y(175))-(k(34)*k(18)*y(174)*y(175))-(k(34)*k(18)*y(174)*y(175))+(k(35)*k(18)*y(233)*y(234))+(k(16)*y(172))+(k(35)*k(18)*y(114)*y(115))+(k(33)*k(1)*y(113)*y(115)) ;
% y(176)'
 (k(19)*((y(178)/k(20))^k(21))*((1+((y(178)/k(22))^k(23)))^(-1)))-(k(19)*y(176)*(1+((y(178)/k(24))^k(25)))) ;
% y(177)'
 (k(7)*((y(178)/k(8))^k(9))*((1+((y(178)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(177)) ;
% y(178)'
 (k(26)*y(179)*y(181))-(k(34)*k(18)*y(177)*y(178))-(k(34)*k(18)*y(177)*y(178))-(k(34)*k(18)*y(177)*y(178))-(k(34)*k(18)*y(177)*y(178))-(k(15)*y(178))-(k(16)*y(178))-(k(16)*y(178))-(k(16)*y(178))-(k(16)*y(178))+(k(16)*y(118))-(k(26)*y(176)*y(178))+(k(35)*k(18)*y(236)*y(237))+(k(16)*y(181))+(k(35)*k(18)*y(117)*y(118))+(k(16)*y(237))+(k(16)*y(175))+(k(37)*k(18)*y(180)*y(181))+(k(35)*k(18)*y(174)*y(175))+(k(33)*k(1)*y(116)*y(118)) ;
% y(179)'
 (k(19)*((y(181)/k(20))^k(21))*((1+((y(181)/k(22))^k(23)))^(-1)))-(k(19)*y(179)*(1+((y(181)/k(24))^k(25)))) ;
% y(180)'
 (k(7)*((y(181)/k(8))^k(9))*((1+((y(181)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(180)) ;
% y(181)'
 -(k(26)*y(179)*y(181))+(k(35)*k(18)*y(177)*y(178))+(k(37)*k(18)*y(239)*y(240))+(k(16)*y(178))-(k(15)*y(181))+(k(27)*k(38))+(k(33)*k(1)*y(119)*y(121))-(k(16)*y(181))-(k(16)*y(181))-(k(16)*y(181))+(k(16)*y(121))+(k(37)*k(18)*y(120)*y(121))-(k(36)*k(18)*y(180)*y(181))-(k(36)*k(18)*y(180)*y(181))-(k(36)*k(18)*y(180)*y(181))+(k(16)*y(240)) ;
% y(182)'
 (k(7)*((y(183)/k(8))^k(9))*((1+((y(183)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(182)) ;
% y(183)'
 -(k(16)*y(183))+(k(37)*k(18)*y(123)*y(124))+(k(16)*y(124))+(k(26)*y(184)*y(186))-(k(15)*y(183))-(k(16)*y(183))+(k(16)*y(186))-(k(36)*k(18)*y(182)*y(183))-(k(36)*k(18)*y(182)*y(183))+(k(35)*k(18)*y(185)*y(186)) ;
% y(184)'
 (k(19)*((y(186)/k(20))^k(21))*((1+((y(186)/k(22))^k(23)))^(-1)))-(k(19)*y(184)*(1+((y(186)/k(24))^k(25)))) ;
% y(185)'
 (k(7)*((y(186)/k(8))^k(9))*((1+((y(186)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(185)) ;
% y(186)'
 (k(16)*y(183))-(k(26)*y(184)*y(186))+(k(16)*y(127))+(k(35)*k(18)*y(188)*y(189))+(k(16)*y(189))-(k(15)*y(186))+(k(26)*y(187)*y(189))+(k(35)*k(18)*y(126)*y(127))-(k(16)*y(186))-(k(16)*y(186))-(k(16)*y(186))+(k(37)*k(18)*y(182)*y(183))-(k(34)*k(18)*y(185)*y(186))-(k(34)*k(18)*y(185)*y(186))-(k(34)*k(18)*y(185)*y(186)) ;
% y(187)'
 (k(19)*((y(189)/k(20))^k(21))*((1+((y(189)/k(22))^k(23)))^(-1)))-(k(19)*y(187)*(1+((y(189)/k(24))^k(25)))) ;
% y(188)'
 (k(7)*((y(189)/k(8))^k(9))*((1+((y(189)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(188)) ;
% y(189)'
 -(k(15)*y(189))-(k(34)*k(18)*y(188)*y(189))-(k(34)*k(18)*y(188)*y(189))-(k(34)*k(18)*y(188)*y(189))-(k(16)*y(189))-(k(16)*y(189))-(k(16)*y(189))+(k(35)*k(18)*y(191)*y(192))-(k(26)*y(187)*y(189))+(k(16)*y(130))+(k(16)*y(186))+(k(26)*y(190)*y(192))+(k(35)*k(18)*y(129)*y(130))+(k(35)*k(18)*y(185)*y(186))+(k(16)*y(192)) ;
% y(190)'
 (k(19)*((y(192)/k(20))^k(21))*((1+((y(192)/k(22))^k(23)))^(-1)))-(k(19)*y(190)*(1+((y(192)/k(24))^k(25)))) ;
% y(191)'
 (k(7)*((y(192)/k(8))^k(9))*((1+((y(192)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(191)) ;
% y(192)'
 (k(35)*k(18)*y(188)*y(189))+(k(16)*y(189))-(k(34)*k(18)*y(191)*y(192))-(k(34)*k(18)*y(191)*y(192))-(k(34)*k(18)*y(191)*y(192))-(k(15)*y(192))+(k(16)*y(133))+(k(35)*k(18)*y(194)*y(195))+(k(16)*y(195))+(k(26)*y(193)*y(195))-(k(26)*y(190)*y(192))+(k(35)*k(18)*y(132)*y(133))-(k(16)*y(192))-(k(16)*y(192))-(k(16)*y(192)) ;
% y(193)'
 (k(19)*((y(195)/k(20))^k(21))*((1+((y(195)/k(22))^k(23)))^(-1)))-(k(19)*y(193)*(1+((y(195)/k(24))^k(25)))) ;
% y(194)'
 (k(7)*((y(195)/k(8))^k(9))*((1+((y(195)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(194)) ;
% y(195)'
 (k(16)*y(136))+(k(35)*k(18)*y(191)*y(192))+(k(35)*k(18)*y(197)*y(198))+(k(35)*k(18)*y(135)*y(136))+(k(16)*y(198))+(k(26)*y(196)*y(198))-(k(34)*k(18)*y(194)*y(195))-(k(34)*k(18)*y(194)*y(195))-(k(34)*k(18)*y(194)*y(195))-(k(16)*y(195))-(k(16)*y(195))-(k(16)*y(195))-(k(15)*y(195))-(k(26)*y(193)*y(195))+(k(16)*y(192)) ;
% y(196)'
 (k(19)*((y(198)/k(20))^k(21))*((1+((y(198)/k(22))^k(23)))^(-1)))-(k(19)*y(196)*(1+((y(198)/k(24))^k(25)))) ;
% y(197)'
 (k(7)*((y(198)/k(8))^k(9))*((1+((y(198)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(197)) ;
% y(198)'
 (k(16)*y(139))+(k(35)*k(18)*y(138)*y(139))+(k(16)*y(201))-(k(15)*y(198))-(k(34)*k(18)*y(197)*y(198))-(k(34)*k(18)*y(197)*y(198))-(k(34)*k(18)*y(197)*y(198))-(k(16)*y(198))-(k(16)*y(198))-(k(16)*y(198))-(k(26)*y(196)*y(198))+(k(26)*y(199)*y(201))+(k(35)*k(18)*y(194)*y(195))+(k(16)*y(195))+(k(35)*k(18)*y(200)*y(201)) ;
% y(199)'
 (k(19)*((y(201)/k(20))^k(21))*((1+((y(201)/k(22))^k(23)))^(-1)))-(k(19)*y(199)*(1+((y(201)/k(24))^k(25)))) ;
% y(200)'
 (k(7)*((y(201)/k(8))^k(9))*((1+((y(201)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(200)) ;
% y(201)'
 (k(16)*y(204))+(k(35)*k(18)*y(141)*y(142))-(k(16)*y(201))-(k(16)*y(201))-(k(16)*y(201))+(k(35)*k(18)*y(197)*y(198))-(k(15)*y(201))+(k(16)*y(198))+(k(26)*y(202)*y(204))-(k(26)*y(199)*y(201))+(k(35)*k(18)*y(203)*y(204))+(k(16)*y(142))-(k(34)*k(18)*y(200)*y(201))-(k(34)*k(18)*y(200)*y(201))-(k(34)*k(18)*y(200)*y(201)) ;
% y(202)'
 (k(19)*((y(204)/k(20))^k(21))*((1+((y(204)/k(22))^k(23)))^(-1)))-(k(19)*y(202)*(1+((y(204)/k(24))^k(25)))) ;
% y(203)'
 (k(7)*((y(204)/k(8))^k(9))*((1+((y(204)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(203)) ;
% y(204)'
 -(k(16)*y(204))-(k(16)*y(204))-(k(16)*y(204))+(k(35)*k(18)*y(144)*y(145))+(k(16)*y(201))-(k(15)*y(204))+(k(26)*y(205)*y(207))+(k(16)*y(145))-(k(26)*y(202)*y(204))+(k(35)*k(18)*y(206)*y(207))-(k(34)*k(18)*y(203)*y(204))-(k(34)*k(18)*y(203)*y(204))-(k(34)*k(18)*y(203)*y(204))+(k(35)*k(18)*y(200)*y(201))+(k(16)*y(207)) ;
% y(205)'
 (k(19)*((y(207)/k(20))^k(21))*((1+((y(207)/k(22))^k(23)))^(-1)))-(k(19)*y(205)*(1+((y(207)/k(24))^k(25)))) ;
% y(206)'
 (k(7)*((y(207)/k(8))^k(9))*((1+((y(207)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(206)) ;
% y(207)'
 (k(16)*y(204))+(k(35)*k(18)*y(209)*y(210))+(k(35)*k(18)*y(147)*y(148))-(k(15)*y(207))+(k(16)*y(210))+(k(26)*y(208)*y(210))-(k(26)*y(205)*y(207))+(k(16)*y(148))-(k(34)*k(18)*y(206)*y(207))-(k(34)*k(18)*y(206)*y(207))-(k(34)*k(18)*y(206)*y(207))+(k(35)*k(18)*y(203)*y(204))-(k(16)*y(207))-(k(16)*y(207))-(k(16)*y(207)) ;
% y(208)'
 (k(19)*((y(210)/k(20))^k(21))*((1+((y(210)/k(22))^k(23)))^(-1)))-(k(19)*y(208)*(1+((y(210)/k(24))^k(25)))) ;
% y(209)'
 (k(7)*((y(210)/k(8))^k(9))*((1+((y(210)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(209)) ;
% y(210)'
 -(k(34)*k(18)*y(209)*y(210))-(k(34)*k(18)*y(209)*y(210))-(k(34)*k(18)*y(209)*y(210))+(k(26)*y(211)*y(213))-(k(16)*y(210))-(k(16)*y(210))-(k(16)*y(210))-(k(26)*y(208)*y(210))+(k(16)*y(151))-(k(15)*y(210))+(k(35)*k(18)*y(212)*y(213))+(k(35)*k(18)*y(206)*y(207))+(k(16)*y(213))+(k(35)*k(18)*y(150)*y(151))+(k(16)*y(207)) ;
% y(211)'
 (k(19)*((y(213)/k(20))^k(21))*((1+((y(213)/k(22))^k(23)))^(-1)))-(k(19)*y(211)*(1+((y(213)/k(24))^k(25)))) ;
% y(212)'
 (k(7)*((y(213)/k(8))^k(9))*((1+((y(213)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(212)) ;
% y(213)'
 (k(16)*y(216))+(k(35)*k(18)*y(209)*y(210))-(k(26)*y(211)*y(213))+(k(16)*y(210))-(k(34)*k(18)*y(212)*y(213))-(k(34)*k(18)*y(212)*y(213))-(k(34)*k(18)*y(212)*y(213))+(k(26)*y(214)*y(216))+(k(35)*k(18)*y(215)*y(216))+(k(16)*y(154))-(k(16)*y(213))-(k(16)*y(213))-(k(16)*y(213))+(k(35)*k(18)*y(153)*y(154))-(k(15)*y(213)) ;
% y(214)'
 (k(19)*((y(216)/k(20))^k(21))*((1+((y(216)/k(22))^k(23)))^(-1)))-(k(19)*y(214)*(1+((y(216)/k(24))^k(25)))) ;
% y(215)'
 (k(7)*((y(216)/k(8))^k(9))*((1+((y(216)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(215)) ;
% y(216)'
 -(k(16)*y(216))-(k(16)*y(216))-(k(16)*y(216))-(k(15)*y(216))+(k(16)*y(219))+(k(35)*k(18)*y(212)*y(213))+(k(16)*y(157))-(k(26)*y(214)*y(216))+(k(35)*k(18)*y(156)*y(157))+(k(35)*k(18)*y(218)*y(219))+(k(26)*y(217)*y(219))-(k(34)*k(18)*y(215)*y(216))-(k(34)*k(18)*y(215)*y(216))-(k(34)*k(18)*y(215)*y(216))+(k(16)*y(213)) ;
% y(217)'
 (k(19)*((y(219)/k(20))^k(21))*((1+((y(219)/k(22))^k(23)))^(-1)))-(k(19)*y(217)*(1+((y(219)/k(24))^k(25)))) ;
% y(218)'
 (k(7)*((y(219)/k(8))^k(9))*((1+((y(219)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(218)) ;
% y(219)'
 (k(16)*y(216))+(k(16)*y(222))-(k(16)*y(219))-(k(16)*y(219))-(k(16)*y(219))-(k(34)*k(18)*y(218)*y(219))-(k(34)*k(18)*y(218)*y(219))-(k(34)*k(18)*y(218)*y(219))-(k(26)*y(217)*y(219))+(k(35)*k(18)*y(215)*y(216))-(k(15)*y(219))+(k(35)*k(18)*y(159)*y(160))+(k(16)*y(160))+(k(26)*y(220)*y(222))+(k(35)*k(18)*y(221)*y(222)) ;
% y(220)'
 (k(19)*((y(222)/k(20))^k(21))*((1+((y(222)/k(22))^k(23)))^(-1)))-(k(19)*y(220)*(1+((y(222)/k(24))^k(25)))) ;
% y(221)'
 (k(7)*((y(222)/k(8))^k(9))*((1+((y(222)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(221)) ;
% y(222)'
 -(k(16)*y(222))-(k(16)*y(222))-(k(16)*y(222))+(k(35)*k(18)*y(162)*y(163))+(k(35)*k(18)*y(224)*y(225))+(k(16)*y(219))+(k(26)*y(223)*y(225))+(k(16)*y(163))+(k(35)*k(18)*y(218)*y(219))+(k(16)*y(225))-(k(26)*y(220)*y(222))-(k(15)*y(222))-(k(34)*k(18)*y(221)*y(222))-(k(34)*k(18)*y(221)*y(222))-(k(34)*k(18)*y(221)*y(222)) ;
% y(223)'
 (k(19)*((y(225)/k(20))^k(21))*((1+((y(225)/k(22))^k(23)))^(-1)))-(k(19)*y(223)*(1+((y(225)/k(24))^k(25)))) ;
% y(224)'
 (k(7)*((y(225)/k(8))^k(9))*((1+((y(225)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(224)) ;
% y(225)'
 (k(16)*y(166))+(k(16)*y(222))-(k(15)*y(225))-(k(34)*k(18)*y(224)*y(225))-(k(34)*k(18)*y(224)*y(225))-(k(34)*k(18)*y(224)*y(225))+(k(35)*k(18)*y(165)*y(166))+(k(16)*y(228))+(k(35)*k(18)*y(227)*y(228))-(k(26)*y(223)*y(225))+(k(26)*y(226)*y(228))-(k(16)*y(225))-(k(16)*y(225))-(k(16)*y(225))+(k(35)*k(18)*y(221)*y(222)) ;
% y(226)'
 (k(19)*((y(228)/k(20))^k(21))*((1+((y(228)/k(22))^k(23)))^(-1)))-(k(19)*y(226)*(1+((y(228)/k(24))^k(25)))) ;
% y(227)'
 (k(7)*((y(228)/k(8))^k(9))*((1+((y(228)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(227)) ;
% y(228)'
 (k(16)*y(169))-(k(15)*y(228))+(k(35)*k(18)*y(224)*y(225))-(k(16)*y(228))-(k(16)*y(228))-(k(16)*y(228))+(k(35)*k(18)*y(168)*y(169))+(k(35)*k(18)*y(230)*y(231))-(k(34)*k(18)*y(227)*y(228))-(k(34)*k(18)*y(227)*y(228))-(k(34)*k(18)*y(227)*y(228))-(k(26)*y(226)*y(228))+(k(16)*y(225))+(k(26)*y(229)*y(231))+(k(16)*y(231)) ;
% y(229)'
 (k(19)*((y(231)/k(20))^k(21))*((1+((y(231)/k(22))^k(23)))^(-1)))-(k(19)*y(229)*(1+((y(231)/k(24))^k(25)))) ;
% y(230)'
 (k(7)*((y(231)/k(8))^k(9))*((1+((y(231)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(230)) ;
% y(231)'
 (k(16)*y(228))-(k(34)*k(18)*y(230)*y(231))-(k(34)*k(18)*y(230)*y(231))-(k(34)*k(18)*y(230)*y(231))+(k(16)*y(234))+(k(35)*k(18)*y(227)*y(228))+(k(35)*k(18)*y(171)*y(172))-(k(15)*y(231))+(k(26)*y(232)*y(234))-(k(26)*y(229)*y(231))-(k(16)*y(231))-(k(16)*y(231))-(k(16)*y(231))+(k(35)*k(18)*y(233)*y(234))+(k(16)*y(172)) ;
% y(232)'
 (k(19)*((y(234)/k(20))^k(21))*((1+((y(234)/k(22))^k(23)))^(-1)))-(k(19)*y(232)*(1+((y(234)/k(24))^k(25)))) ;
% y(233)'
 (k(7)*((y(234)/k(8))^k(9))*((1+((y(234)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(233)) ;
% y(234)'
 -(k(15)*y(234))+(k(35)*k(18)*y(236)*y(237))+(k(35)*k(18)*y(230)*y(231))-(k(16)*y(234))-(k(16)*y(234))-(k(16)*y(234))+(k(16)*y(237))-(k(26)*y(232)*y(234))+(k(26)*y(235)*y(237))+(k(16)*y(175))+(k(16)*y(231))+(k(35)*k(18)*y(174)*y(175))-(k(34)*k(18)*y(233)*y(234))-(k(34)*k(18)*y(233)*y(234))-(k(34)*k(18)*y(233)*y(234)) ;
% y(235)'
 (k(19)*((y(237)/k(20))^k(21))*((1+((y(237)/k(22))^k(23)))^(-1)))-(k(19)*y(235)*(1+((y(237)/k(24))^k(25)))) ;
% y(236)'
 (k(7)*((y(237)/k(8))^k(9))*((1+((y(237)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(236)) ;
% y(237)'
 (k(35)*k(18)*y(177)*y(178))-(k(15)*y(237))+(k(37)*k(18)*y(239)*y(240))+(k(16)*y(178))-(k(34)*k(18)*y(236)*y(237))-(k(34)*k(18)*y(236)*y(237))-(k(34)*k(18)*y(236)*y(237))+(k(16)*y(234))+(k(26)*y(238)*y(240))-(k(16)*y(237))-(k(16)*y(237))-(k(16)*y(237))-(k(26)*y(235)*y(237))+(k(35)*k(18)*y(233)*y(234))+(k(16)*y(240)) ;
% y(238)'
 (k(19)*((y(240)/k(20))^k(21))*((1+((y(240)/k(22))^k(23)))^(-1)))-(k(19)*y(238)*(1+((y(240)/k(24))^k(25)))) ;
% y(239)'
 (k(7)*((y(240)/k(8))^k(9))*((1+((y(240)/k(10))^k(11)))^(-1)))-(k(14)*k(7)*y(239)) ;
% y(240)'
 -(k(15)*y(240))+(k(27)*k(38))-(k(36)*k(18)*y(239)*y(240))-(k(36)*k(18)*y(239)*y(240))+(k(35)*k(18)*y(236)*y(237))+(k(16)*y(181))-(k(26)*y(238)*y(240))+(k(16)*y(237))+(k(37)*k(18)*y(180)*y(181))-(k(16)*y(240))-(k(16)*y(240)) ;
];
end

